#ifndef CONVEX_HPP_INCLUDED
#define CONVEX_HPP_INCLUDED

#include <vector>
#include "Point.hpp"
#include "Box.hpp"

/** @addtogroup Types
* @{ */
class Convex
{
    public:
        std::vector<Point> Vertices;

        /**
        * @brief Default Constructor, constructs a Convex with null Vertices
        * @par Description
        *   Default Constructor, constructs a Convex with null Vertices
        */
        Convex();
        Convex(std::vector<Point> Vertices);
        /**
        * @brief Constructs a Convex, by copying another
		* @param const Convex& C  The Convex to "copy"
		*/
        Convex(const Convex& C);

        /**
		* @brief Returns True if the Convex has more than two Vertices
		* @return True if the Convex has more than two Vertices
		*/
        virtual bool Valid() const;
        /**
		* @brief Returns True if the Convex contains a Point
		* @return True if the Convex contains a Point
		*/
        virtual bool Contains(const Point& P) const;
        /**
		* @brief Returns the middle Point of the Convex
		* @return The middle Point of the Convex
		*/
        Point GetMiddle() const;
        /**
		* @brief Returns a Box of the Convex
		* @return A Box of the Convex
		*/
        Box GetBox() const;
        /**
		* @brief Returns a random Point using Hybrid Distribution
		* @return A random Point using Hybrid Distribution
		* @see @ref HybridRandomDocs
		* @see @ref MissChanceFollowupDocs
		*/
        Point GetHybridRandomPoint(double ProbabilityX, double ProbabilityY, double StandardDeviationX, double StandardDeviationY, bool CheckMissFollowupChance = true) const;

        Convex operator+(const Point& P) const;
        Convex operator-(const Point& P) const;
        Convex& operator+=(const Point& P);
        Convex& operator-=(const Point& P);
        friend std::ostream& operator<<(std::ostream& OS, const Convex& C);
        operator bool() const;
        virtual ~Convex();
};

/** @} */

#endif // CONVEX_HPP_INCLUDED
